===================================
Ogrodje za oglaševanje po Discordu
===================================


.. figure:: ./DEP/logo.png
    :height: 4cm

    Logotip projekta (Narejen z DALL-E & Adobe Photoshop)


.. toctree::

    purpose
    design_development/index
